about summary refs log tree commit diff stats
path: root/lib/quickjs/libregexp-opcode.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/quickjs/libregexp-opcode.h')
-rw-r--r--lib/quickjs/libregexp-opcode.h3
1 files changed, 1 insertions, 2 deletions
diff --git a/lib/quickjs/libregexp-opcode.h b/lib/quickjs/libregexp-opcode.h
index f90c23b3..189d1215 100644
--- a/lib/quickjs/libregexp-opcode.h
+++ b/lib/quickjs/libregexp-opcode.h
@@ -50,8 +50,7 @@ DEF(range32, 3) /* variable length */
 DEF(lookahead, 5)
 DEF(negative_lookahead, 5)
 DEF(push_char_pos, 1) /* push the character position on the stack */
-DEF(bne_char_pos, 5) /* pop one stack element and jump if equal to the character
- position */
+DEF(check_advance, 1) /* pop one stack element and check that it is different from the character position */
 DEF(prev, 1) /* go to the previous char */
 DEF(simple_greedy_quant, 17)